# PythonPackageVersionMetadataResponseMetadataImportlibMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**entry_points** | [**list[PythonPackageVersionMetadataResponseMetadataImportlibMetadataEntryPoints]**](PythonPackageVersionMetadataResponseMetadataImportlibMetadataEntryPoints.md) |  |
**files** | **list[object]** | Files shipped with the Python package |
**metadata** | **object** | Core Python packaging metadata extracted |
**requires** | **list[str]** | Python requirements of the given package |
**version** | **str** | Version of the Python package based on importlib metadata detection  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

